@@ -11,7 +11,7 @@
 
 
 /* we USE GNU because of the getline function */
-#define _GNU_SOURCE
+//#define _GNU_SOURCE
 
 #include <stdio.h>
 #include "includes.h"
@@ -64,7 +64,7 @@ void free_regex() {
 }
 
 /* set default values */
-int inConfig::initGl() {
+void inConfig::initGl() {
   getParams()->setParam("fromaddr", new inPChar(L2M_FROMADDR));
   getParams()->setParam("sendmail", new inPChar(L2M_SENDMAIL));
   getParams()->setParam("template", new inPChar(L2M_TEMPLATE));
@@ -395,7 +395,7 @@ int inTemplate::readContents() {
   }
 
   int i = 0;
-  char content[L2M_MSG_SIZE];
+  char content[L2M_MSG_SIZE+1];
   content[0] = '\0';
 
   while (!feof(inf)) {
@@ -415,4 +415,5 @@ int inTemplate::readContents() {
   contents = (char*)malloc(strlen(content)+1);
 
   if (contents) strncpy(contents, content, strlen(content)+1);
+  return 0;
 }
