@@ -25,7 +25,7 @@ int inPattern::matches(const string& aLine) {
   return (regexec(&rPattern, aLine.c_str(), 0, 0, 0) == 0);
 }
 
-int inLogfile::checkPatternIn(list<inMsg*>& msgQ, const string& eing) {
+void inLogfile::checkPatternIn(list<inMsg*>& msgQ, const string& eing) {
   list<inPattern*>::iterator first = pattern.begin();
   list<inPattern*>::iterator last  = pattern.end();
 
@@ -142,11 +142,11 @@ string inMsg::build() {
 		       hostname);
 }
 
-int inMsg::addZeile(const string& zeile) {
+void inMsg::addZeile(const string& zeile) {
   zeilen.insert(zeilen.end(), zeile);
   lines++;
   int maxlines = mailto->getParams()->getParamValueAsInt("maxlines");
-  if (maxlines > 0 && zeilen.size() > maxlines) {
+  if (maxlines > 0 && zeilen.size() > static_cast<size_t>(maxlines)) {
     zeilen.erase(zeilen.begin());
   }
   if (lines == 1) zaehler = 0;
