@@ -18,17 +18,20 @@
 #include <stdlib.h>
 #include <string.h>
 #include <regex.h>
-#include <list.h>
+#include <list>
 #include "defines.h"
 #include <errno.h>
 #include <stdio.h>
-#include <map.h>
+#include <map>
 #include <syslog.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string>
 
+using std::list;
+using std::map;
+
 class inDaemon;
 extern class inDaemon *thisDaemon;
 
@@ -83,12 +86,12 @@ class inParam {
   inParam() { ; }
   virtual ~inParam() { ; }
   
-  virtual int getValueAsInt() = NULL;
-  virtual char* getValueAsChar() = NULL;
+  virtual int getValueAsInt() = 0;
+  virtual char* getValueAsChar() = 0;
 
   /* returns 0 on success */
-  virtual int setValue(int) = NULL;
-  virtual int setValue(char*) = NULL;
+  virtual int setValue(int) = 0;
+  virtual int setValue(char*) = 0;
 };
 
 class inPChar : public inParam {
@@ -110,7 +113,7 @@ class inPChar : public inParam {
     value = strdup(avalue);
     return (value == NULL);
   }
-  virtual int setValue(int i) { return 1; }
+  virtual int setValue(int /* i */) { return 1; }
 };
 
 class inPInt : public inParam {
@@ -310,11 +313,11 @@ class inMsg {
     addZeile(zeile);
   }
 
-  int update() { zaehler++; }
+  void update() { zaehler++; }
 
-  int done() { _done=1; zaehler = 0; lines = 0; }
+  void done() { _done=1; zaehler = 0; lines = 0; }
   int isDone() { return _done; }
-  int addZeile(const std::string& zeile);
+  void addZeile(const std::string& zeile);
 
   int isReady() {
     if (!lines) return 0;
@@ -394,7 +397,9 @@ class inLogfile : public inCfCommon {
     }
 
     /* no new data but modification time changed */
-    if ( (!new_data_appeared) && (sbuf.st_mtime > lfStat.st_mtime) ) {
+    /* use cached filesize to check whether there is new data,
+     * to avoid a race condition */
+    if ( (sbuf.st_size == lfStat.st_size) && (sbuf.st_mtime > lfStat.st_mtime) ) {
       /* file is newer */
       return 1;
     }
@@ -414,7 +419,7 @@ class inLogfile : public inCfCommon {
     return (res);
   }
 
-  int checkPatternIn(list<inMsg*>&, const std::string&); 
+  void checkPatternIn(list<inMsg*>&, const std::string&); 
 };
 
 /* aus config.cc */
@@ -460,7 +465,7 @@ class inConfigFile : public inCfCommon {
     return parseConfig(); 
   }
 
-  int addLogfile(inLogfile* logfile) { logfiles.insert(logfiles.end(), 
+  void addLogfile(inLogfile* logfile) { logfiles.insert(logfiles.end(), 
 						       logfile); }
   inLogfile* addLogfile(char *logfile) {
     inLogfile* t = new inLogfile(logfile, getParams());
@@ -490,7 +495,7 @@ class inConfig : public inCfCommon {
   }
 
  protected:
-  int initGl();
+  void initGl();
   
   int doConfigFile(char *afilename);
   
@@ -509,7 +514,7 @@ class inConfig : public inCfCommon {
     return parseConfig(filename); 
   }
 
-  int free() {
+  void free() {
     configfiles.erase(configfiles.begin(), configfiles.end());
   };
 
@@ -558,20 +563,20 @@ class inDaemon {
   int open(inLogfile*, int *fd);
 
   /* sends messages and terminates */
-  int signalTERM() {
+  void signalTERM() {
     bSigTerm++;
   }
 
   /* rereads configuration files */
-  int signalHUP() {
+  void signalHUP() {
     bSigHUP++;
   }
 
   /* sends messages */
-  int flush();
+  void flush();
 
   int openFiles();
-  int closeFiles(int);
+  void closeFiles(int);
 };
 
 
