@@ -21,7 +21,7 @@
 #include <syslog.h>
 #include <signal.h>
 
-int usage (char *name) {
+void usage (char *name) {
   printf("usage: %s [-f config file] [-l] [-N] [-V] [-v] [-h|?]\n", name);
   printf(" -f specifies a config file\n");
   printf(" -N do not fork into background, log to stderr\n");
@@ -60,13 +60,14 @@ int printlog(int priority, char *format, ...) {
 	return -1;
       }
     }                                                              
-    syslog(priority, p);
+    syslog(priority, "%s", p);
     free(p);
   } else {
     va_start (ap, format);
     vfprintf(stderr, format, ap);
     va_end (ap);
   }
+  return 0;
 }	
 
 void sigHandler (int signum) {
