@@ -85,7 +85,7 @@ int inDaemon::openFiles() {
   return(i);
 }
 
-int inDaemon::closeFiles(int max_fd) {
+void inDaemon::closeFiles(int max_fd) {
   for (int i=0;i<max_fd;i++) {
     close(files[i]);
   }
@@ -141,7 +141,7 @@ int inDaemon::run() {
 	  int rdsize;
 
 	  while ((rdsize = read(files[i], buf, bufsize)) > 0)
-	    for (unsigned int t = 0; t < rdsize; t++)
+	    for (unsigned int t = 0; t < static_cast<size_t>(rdsize); t++)
 	      if (buf[t] == '\n')
 	      {
 		// Have a line
@@ -229,7 +229,7 @@ int inDaemon::run() {
   return 0;
 }
 
-int inDaemon::flush() {
+void inDaemon::flush() {
   list<inMsg*>::iterator fi = msgQueue.begin();
   list<inMsg*>::iterator la = msgQueue.end();
   while (fi != la) {
